package com.f1rq.lifemap.components

import androidx.compose.foundation.layout.*
import androidx.compose.foundation.shape.RoundedCornerShape
import androidx.compose.material3.Icon
import androidx.compose.material3.IconButton
import androidx.compose.foundation.background
import androidx.compose.foundation.layout.fillMaxWidth
import androidx.compose.foundation.layout.padding
import androidx.compose.runtime.Composable
import androidx.compose.ui.Alignment
import androidx.compose.ui.unit.dp
import androidx.compose.ui.Modifier
import androidx.compose.ui.graphics.Color
import androidx.compose.ui.res.painterResource
import androidx.compose.ui.tooling.preview.Preview
import com.f1rq.lifemap.ui.theme.MainBG
import com.f1rq.lifemap.ui.theme.InactiveNavColor
import com.f1rq.lifemap.ui.theme.ActiveNavColor
import com.f1rq.lifemap.ui.theme.ButtonColor
import com.f1rq.lifemap.R.drawable.navbar_listview_button
import com.f1rq.lifemap.R.drawable.navbar_mapview_button

@Composable
fun NavBar(
    onMapViewClicked: () -> Unit = {},
    onListViewClicked: () -> Unit = {},
    mapViewBackgroundColor: Color = ActiveNavColor,
    listViewBackgroundColor: Color = InactiveNavColor,
) {
    Row(
        modifier = Modifier
            .fillMaxWidth()
            .background(
                color = MainBG,
                shape = RoundedCornerShape(
                    topStart = 16.dp,
                    topEnd = 16.dp,
                    bottomStart = 0.dp,
                    bottomEnd = 0.dp
                )
            )
            .padding(
                top = 12.dp,
                bottom = WindowInsets.navigationBars.asPaddingValues().calculateBottomPadding() + 6.dp,
            ),
        verticalAlignment = Alignment.CenterVertically
    ) {
        // Left Half - Map View Button
        Box(
            modifier = Modifier
                .weight(1f),
            contentAlignment = Alignment.Center
        ) {
            IconButton(
                onClick = onMapViewClicked,
                modifier = Modifier
                    .size(48.dp)
                    .background(
                        color = mapViewBackgroundColor,
                        shape = RoundedCornerShape(16.dp)
                    )
            ) {
                Icon(
                    painter = painterResource(id = navbar_mapview_button),
                    contentDescription = "Map View",
                    modifier = Modifier
                        .requiredSize(24.dp),
                    tint = ButtonColor
                )
            }
        }

        // Right Half - List View Button
        Box(
            modifier = Modifier
                .weight(1f),
            contentAlignment = Alignment.Center
        ) {
            IconButton(
                onClick = onListViewClicked,
                modifier = Modifier
                    .size(48.dp)
                    .background(
                        color = listViewBackgroundColor,
                        shape = RoundedCornerShape(16.dp)
                    )
            ) {
                Icon(
                    painter = painterResource(id = navbar_listview_button),
                    contentDescription = "List View",
                    modifier = Modifier
                        .requiredSize(24.dp),
                    tint = ButtonColor
                )
            }
        }
    }
}


@Preview
@Composable
fun NavBarPreview() {
    NavBar()
}